==> huaweicloudsdkrgc-3.1.76-py2.py3-none-any.whl: huaweicloudsdkrgc/v1/model/landing_zone_error_message.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class LandingZoneErrorMessage:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'level': 'str',
        'message': 'str'
    }

    attribute_map = {
        'level': 'level',
        'message': 'message'
    }

    def __init__(self, level=None, message=None):
        """LandingZoneErrorMessage

        The model defined in huaweicloud sdk

        :param level: Landing Zone的错误级别。包括致命fatal和错误error。
        :type level: str
        :param message: Landing Zone详细的错误信息。
        :type message: str
        """
        
        

        self._level = None
        self._message = None
        self.discriminator = None

        if level is not None:
            self.level = level
        if message is not None:
            self.message = message

    @property
    def level(self):
        """Gets the level of this LandingZoneErrorMessage.

        Landing Zone的错误级别。包括致命fatal和错误error。

        :return: The level of this LandingZoneErrorMessage.
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """Sets the level of this LandingZoneErrorMessage.

        Landing Zone的错误级别。包括致命fatal和错误error。

        :param level: The level of this LandingZoneErrorMessage.
        :type level: str
        """
        self._level = level

    @property
    def message(self):
        """Gets the message of this LandingZoneErrorMessage.

        Landing Zone详细的错误信息。

        :return: The message of this LandingZoneErrorMessage.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this LandingZoneErrorMessage.

        Landing Zone详细的错误信息。

        :param message: The message of this LandingZoneErrorMessage.
        :type message: str
        """
        self._message = message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LandingZoneErrorMessage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrgc-3.1.85-py2.py3-none-any.whl: huaweicloudsdkrgc/v1/model/landing_zone_error_message.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class LandingZoneErrorMessage:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'level': 'str',
        'message': 'str'
    }

    attribute_map = {
        'level': 'level',
        'message': 'message'
    }

    def __init__(self, level=None, message=None):
        """LandingZoneErrorMessage

        The model defined in huaweicloud sdk

        :param level: Landing Zone的错误级别。
        :type level: str
        :param message: Landing Zone详细的错误信息。
        :type message: str
        """
        
        

        self._level = None
        self._message = None
        self.discriminator = None

        if level is not None:
            self.level = level
        if message is not None:
            self.message = message

    @property
    def level(self):
        """Gets the level of this LandingZoneErrorMessage.

        Landing Zone的错误级别。

        :return: The level of this LandingZoneErrorMessage.
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """Sets the level of this LandingZoneErrorMessage.

        Landing Zone的错误级别。

        :param level: The level of this LandingZoneErrorMessage.
        :type level: str
        """
        self._level = level

    @property
    def message(self):
        """Gets the message of this LandingZoneErrorMessage.

        Landing Zone详细的错误信息。

        :return: The message of this LandingZoneErrorMessage.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this LandingZoneErrorMessage.

        Landing Zone详细的错误信息。

        :param message: The message of this LandingZoneErrorMessage.
        :type message: str
        """
        self._message = message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LandingZoneErrorMessage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
